@@ -102,7 +102,9 @@ sub sessioncgi ($$) {
 	}
 	elsif ($cgi->param("do") eq "sshkey") {
 		print "Content-Type: text/plain\n\n";
-		print readfile(get_ssh_public_key())."\n";
+		foreach my $f (get_ssh_public_keys()) {
+			print readfile($f)."\n";
+		}
 		exit 0;
 	}
 }
@@ -176,7 +178,7 @@ sub deletesite ($$){
 		method => 'POST',
 		javascript => 0,
 		params => $cgi,
-		action => $config{cgiurl},
+		action => IkiWiki::cgiurl(),
 		stylesheet => 1,
 		fields => [qw{do}],
 	);      
@@ -460,31 +462,31 @@ sub handlechangedsetup {
 	# Drop lock; ikisite takes the lock itself.
 	IkiWiki::unlockwiki();
 
-	# If ipv6 was enabled or disabled, need to refresh dns.
-	IkiWiki::Hosting::getshell("ikisite-wrapper", "enabledns", $config{hostname});
-
 	# Commit any changes to the setup file into the setup branch.
 	IkiWiki::Hosting::getshell("ikisite", "commitsetup", $config{hostname});
+
+	# Re-enable the site for changes to eg, redirect_to_https or dns.
+	# This can't enable any site that's not enabled, since the site has
+	# to be enabled already for this cgi to be run.
+	IkiWiki::Hosting::getshell("ikisite-wrapper", "enable", $config{hostname});
+	
 	exit;
 }
 
-# Returns path of ssh public key.
-# If no key exists, one is created. (Can be a little slow.)
-sub get_ssh_public_key {
-	my @keys;
-	my $findkeys=sub { @keys=glob("$ENV{HOME}/.ssh/id_*.pub") };
-	$findkeys->();
-	if (! @keys) {
-		my $ret=system("ssh-keygen", "-q", "-t", "rsa",
-			"-f", "$ENV{HOME}/.ssh/id_rsa",
+# Returns paths of ssh public keys.
+# If no ed25519 key exists, one is created. (Can be a little slow.)
+sub get_ssh_public_keys {
+	if (! -e "$ENV{HOME}/.ssh/id_ed25519.pub") {
+		system("ssh-keygen", "-q", "-t", "ed25519",
+			"-f", "$ENV{HOME}/.ssh/id_ed25519",
 			"-N", "",
 			"-C", $config{wikiname});
-			$findkeys->();
-		if ($ret !=0 || ! @keys) {
-			error "ssh-keygen failed";
-		}
 	}
-	return shift(@keys);
+	my @keys=glob("$ENV{HOME}/.ssh/id_*.pub");
+	if (! @keys) {
+		error "ssh-keygen failed";
+	}
+	return @keys;
 }
 
 sub analog_report ($$) {
